@@ -1,9 +1,12 @@
 import pyroll.core as core
 from pyroll.core import (
-    BoxGroove, ConstrictedBoxGroove, SquareGroove, DiamondGroove, RoundGroove, FalseRoundGroove,
+    BoxGroove, ConstrictedBoxGroove, SquareGroove, DiamondGroove, RoundGroove, FalseRoundGroove, GothicGroove,
+    UpsetBoxGroove, UpsetOvalGroove,
     CircularOvalGroove, FlatOvalGroove, SwedishOvalGroove, ConstrictedSwedishOvalGroove, Oval3RadiiGroove,
     Oval3RadiiFlankedGroove, SplineGroove, GenericElongationGroove, FlatGroove, Transport, RollPass, Unit, Roll,
-    Profile, Rotator, PassSequence, Hook, HookHost, HookFunction
+    Profile, Rotator, PassSequence, Hook, HookHost, HookFunction,
+    DeformationUnit, DiskElementUnit, ConstrictedUpsetBoxGroove, ConstrictedCircularOvalGroove, HexagonalGroove,
+    ThreeRollPass,
 )
 
 import pyroll.freiberg_flow_stress as freiberg_flow_stress
@@ -12,8 +15,8 @@ from pyroll.freiberg_flow_stress import FreibergFlowStressCoefficients
 import pyroll.integral_thermal as integral_thermal
 import pyroll.hensel_power_and_labour as hensel_power_and_labour
 import pyroll.wusatowski_spreading as wusatowski_spreading
-import pyroll.hitchcock_roll_flattening as hitchcock_roll_flattening
 import pyroll.lendl_equivalent_method as lendl_equivalent_method
+import pyroll.zouhar_contact as zouhar_contact
 
 import pyroll.report as report
 import pyroll.export as export
